==> cpsi-react-web-component-app-0.5.0.tgz: package/src/components/CardComponent.jsx <==
import { Card, CardActionArea, CardContent, Typography } from '@material-ui/core';
import React, { useState, useEffect } from 'react';
import '../App.css';
import headingLogo from "./Open Period Card Icon.png";

type Props = {
    header: string,
    opendate: string,
    duedate: string,
    closedate: string,
    description: string
};
export default function CardComponent({ header, opendate, duedate, closedate, description }: Props) {
    return (
        <Card>
            <CardActionArea>
                <CardContent>
                    <div class="period-large-card">
                        <div class="card-inner-container">
                            <div class="card-title">
                                <div class="open-period-card-icon">
                                    <div class="Group">
                                        <div class="Vector">
                                            <img src={headingLogo} alt='headingLogo' class="heading-logo" />
                                        </div>
                                    </div>
                                </div>
                                <div class="card-title-text">
                                    <div class="page-title">
                                        <div class="reporting-period-text">
                                            {header}
                                        </div>
                                    </div>
                                </div>
                                <div class="card-menu">
                                    <div class="three-dots-icon">
                                        <div class="three-dots">
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="card-dates-bar">
                                <div class="frame-1">
                                    <p class="open-date">
                                        <b>Open Date:</b> {opendate}
                                    </p>
                                </div>
                                <div class="frame-2">
                                    <p class="due-date">
                                        <b>Due Date:</b> {duedate }
                                    </p></div>
                                <div class="frame-3">
                                    <p class="close-date">
                                        <b>Close Date:</b> {closedate}
                                    </p>
                                </div>
                            </div>
                            <div class="card-additional-text">
                                <p class="reporting-period-description">
                                    Reporting Period Description
                                </p>
                                <p class="additional-information-text">
                                    {description}
                                </p>
                            </div>
                            <div class="card-button">
                                <div class="general-button">
                                    <p class="button">Select Period</p>
                                </div>
                            </div>

                        </div>
                    </div>
                </CardContent>
            </CardActionArea >
        </Card >
    );
};

==> cpsi-react-web-component-app-0.6.0.tgz: package/src/components/CardComponent.jsx <==
import { Card, CardActionArea, CardContent, Typography } from '@material-ui/core';
import React, { useState, useEffect } from 'react';
import '../App.css';
import headingLogo from "./Open Period Card Icon.png";

type Props = {
    header: string,
    opendate: string,
    duedate: string,
    closedate: string,
    description: string,
    index: number
};
export default function CardComponent({ header, opendate, duedate, closedate, description, index }: Props) {
    return (
        <Card>
            {/*<CardActionArea>*/}
                <CardContent>
                    <div class="period-large-card">
                        <div class="card-inner-container">
                            <div class="card-title">
                                <div class="open-period-card-icon">
                                    <div class="Group">
                                        <div class="Vector">
                                            <img src={headingLogo} alt='headingLogo' class="heading-logo" />
                                        </div>
                                    </div>
                                </div>
                                <div class="card-title-text">
                                    <div class="page-title">
                                        <div class="reporting-period-text">
                                            {header}
                                        </div>
                                    </div>
                                </div>
                                <div class="card-menu">
                                    <div class="three-dots-icon">
                                        <div class="three-dots">
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                            <div class="three-dots-rectangle"></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="card-dates-bar">
                                <div class="frame-1">
                                    <p class="open-date">
                                        <b>Open Date:</b> {opendate}
                                    </p>
                                </div>
                                <div class="frame-2">
                                    <p class="due-date">
                                        <b>Due Date:</b> {duedate}
                                    </p></div>
                                <div class="frame-3">
                                    <p class="close-date">
                                        <b>Close Date:</b> {closedate}
                                    </p>
                                </div>
                            </div>
                            <div class="card-additional-text">
                                <p class="reporting-period-description">
                                    Reporting Period Description
                                </p>
                                <p class="additional-information-text">
                                    {description}
                                </p>
                            </div>
                            <div class="card-button">
                                <div class="general-button">
                                    <p class="button">Select Period</p>
                                </div>
                            </div>

                        </div>
                    </div>
                </CardContent>
            {/*</CardActionArea >*/}
        </Card >
    );
};
